@@ -41,6 +41,7 @@ class Environment(Component):
         self._multinode_configured = False
         self._display_camera = None
         self.is_material_mode_custom = False
+        self._node_name = None
         # Add empty object holdings MORSE Environment's properties
         # for UTM modifier configutation ( uses env.properties(...) )
         bpymorse.deselect_all()
@@ -54,7 +55,8 @@ class Environment(Component):
 
     def is_internal_camera(self, camera):
         return not self._multinode_configured or \
-            camera._bpy_object.parent.name in self.multinode_distribution[node_name]
+            self._node_name in self.multinode_distribution and \
+            camera._bpy_object.parent.name in self.multinode_distribution[self._node_name]
 
     def _write_multinode(self, node_name):
         """ Configure this node according to its name
@@ -200,6 +202,7 @@ class Environment(Component):
     def _cfg_camera_scene(self):
         scene = bpymorse.get_context_scene()
         scene.name = 'S.MORSE_ENV'
+        scene.game_settings.physics_engine = 'NONE'
         from morse.builder.sensors import VideoCamera
         cfg_camera_scene = {}
         for component in AbstractComponent.components:
@@ -234,6 +237,15 @@ class Environment(Component):
             if hasattr(component, "after_renaming"):
                 component.after_renaming()
 
+        # Compute node name
+        if name == None:
+            try:
+                self._node_name = os.environ["MORSE_NODE"]
+            except KeyError:
+                self._node_name = os.uname()[1]
+        else:
+            self._node_name = name
+
         # Create a new scene for each camera, with specific render resolution
         # Must be done at the end of the builder script, after renaming
         # and before adding 'Scene_Script_Holder'
@@ -243,6 +255,10 @@ class Environment(Component):
         bpymorse.new_scene(type='LINK_OBJECTS')
         scene = bpymorse.get_context_scene()
         scene.name = 'S.MORSE_LOGIC'
+        scene.game_settings.physics_engine = 'BULLET'
+        # set simulation view resolution (4:3)
+        scene.render.resolution_x = 800
+        scene.render.resolution_y = 600
 
         # define 'Scene_Script_Holder' as the blender object of Enrivonment
         if not 'Scene_Script_Holder' in bpymorse.get_objects():
@@ -255,15 +271,9 @@ class Environment(Component):
         _properties = bpymorse.get_properties(bpymorse.get_object('MORSE.Properties'))
         self.properties(**_properties)
 
-        # Default node name
-        if name == None:
-            try:
-                name = os.environ["MORSE_NODE"]
-            except KeyError:
-                name = os.uname()[1]
         # Write the configuration of the datastreams, and node configuration
         Configuration.write_config()
-        self._write_multinode(name)
+        self._write_multinode(self._node_name)
 
         # Change the Screen material
         if self._display_camera:
@@ -273,7 +283,13 @@ class Environment(Component):
         self.properties(environment_file = str(self._environment_file))
 
         if self.fastmode:
-            self.set_material_mode('SINGLETEXTURE')
+            # SINGLETEXTURE support has been removed between 2.69 and
+            # 2.70. Handle properly the case where it is not defined
+            # anymore.
+            try:
+                self.set_material_mode('SINGLETEXTURE')
+            except TypeError:
+                self.set_material_mode('MULTITEXTURE')
             self.set_viewport("WIREFRAME")
         elif not self.is_material_mode_custom:
             # make sure OpenGL shading language shaders (GLSL) is the
@@ -296,6 +312,7 @@ class Environment(Component):
         camera_fp.game.properties['Speed'].value = self._camera_speed
         camera_fp.data.clip_start = self._camera_clip_start
         camera_fp.data.clip_end   = self._camera_clip_end
+        camera_fp.data.lens = 20 # set focal length in mm
         # Make CameraFP the active camera
         bpymorse.deselect_all()
         camera_fp.select = True
