@@ -246,7 +246,8 @@ def joysticks():
         return None
 
 def isfastmode():
-    if not fake:
-        return (bge.render.getMaterialMode() == bge.render.KX_TEXFACE_MATERIAL)
-    else:
-        return False
+    for area in bpy.context.window.screen.areas:
+        if area.type == 'VIEW_3D':
+            for space in area.spaces:
+                if space.type == 'VIEW_3D':
+                    return space.viewport_shade == 'WIREFRAME'
