@@ -2,16 +2,22 @@ import logging; logger = logging.getLogger("morse." + __name__)
 import morse.core.robot
 
 
-class QuadrotorClass(morse.core.robot.Robot):
-    """ Class definition for the Quad2012 (Club Micro Drone
-        ISAE-Toulouse FRANCE).  Sub class of Morse_Object.
+class Quadrotor(morse.core.robot.Robot):
+    """
+    Definition of a generic **quadrotor** without ``Rigid Body`` physics.
+    It is expected to be used with actuators such as:
+     - :doc:`../actuators/stabilized_quadrotor`
+
+    .. note::
+
+        The rotation of the rotors is fixed and only for show. Its speed
+        can be adjusted in the Logic panel in Blender (shown with
+        :kbd:`F4`) when the **cube** object are selected.
     """
 
+    _name = 'Quadrotor'
+
     def __init__(self, obj, parent=None):
-        """ Constructor method.
-            Receives the reference to the Blender object.
-            Optionally it gets the name of the object's parent,
-            but that information is not currently used for a robot. """
         # Call the constructor of the parent class
         logger.info('%s initialization' % obj.name)
         super(self.__class__, self).__init__(obj, parent)
