@@ -55,10 +55,13 @@ class Camera(morse.core.sensor.Sensor):
         self._camera_running = False
 
         import camera_scene # file like 'component_config.py' in the .blend
-        self.scene_name = camera_scene.camera_scene[self.bge_object.name]
-        blenderapi.add_scene(self.scene_name, overlay=0)
+        if self.bge_object.name in camera_scene.camera_scene:
+            self.scene_name = camera_scene.camera_scene[self.bge_object.name]
+            blenderapi.add_scene(self.scene_name, overlay=0)
+            logger.info('Component initialized, runs at %.2f Hz', self.frequency)
+        else:
+            logger.info('External camera')
 
-        logger.info('Component initialized, runs at %.2f Hz', self.frequency)
 
     def default_action(self):
         """ Update the texture image. """
